@@ -42,7 +42,7 @@ sub maybe_sleep($self) {
 }
 
 
-sub start($self) { $self->maybe_sleep while $self->tick; }
+sub start($self) { local $SIG{PIPE} = 'IGNORE'; $self->maybe_sleep while $self->tick; }
 
 1;
 
@@ -58,7 +58,7 @@ Evo::Loop::Comp
 
 =head1 VERSION
 
-version 0.0183
+version 0.0187
 
 =head1 AUTHOR
 
