@@ -87,7 +87,9 @@ sub d_resolve($self, $x) : Role {
       $x = $sync->v;    # and next, but it's already last in loop
       next;
     }
-    die "Should't be here";
+
+    # 2.3.3.4
+    return $self->d_fulfill($x);
   }
 }
 
@@ -157,7 +159,7 @@ Evo::Promises::Promise::Driver
 
 =head1 VERSION
 
-version 0.0183
+version 0.0187
 
 =head1 AUTHOR
 
